ContactPoint class Physics

One contact within a collision manifold.

Constructors

ContactPoint({required Vector3 worldPosition, required Vector3 worldNormal, required double impulse, required double separation})

Properties

hashCode int
The hash code for this object.
no setterinherited
impulse double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separation double
final
worldNormal → Vector3
final
worldPosition → Vector3
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited