FixedJointDesc class Physics

Welds the two bodies at their current relative pose.

Inheritance

Constructors

FixedJointDesc({required int bodyA, required int bodyB, Vector3? localAnchorA, Vector3? localAnchorB, bool collisionsEnabled = false})

Properties

bodyA int
finalinherited
bodyB int
finalinherited
collisionsEnabled bool
Whether the joined bodies still collide with each other.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
localAnchorA → Vector3
final
localAnchorB → Vector3
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited