RayShapeHit class Physics

Internal hit record. The owning world wraps this in a RaycastHit.

Constructors

RayShapeHit(double distance, Vector3 worldPoint, Vector3 worldNormal)

Properties

distance double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
worldNormal → Vector3
final
worldPoint → Vector3
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited