SimRaycastHit class Physics

A raycast result at the simulation level, keyed by collider handle.

Implementers

Constructors

SimRaycastHit({required int colliderHandle, required Vector3 worldPoint, required Vector3 worldNormal, required double distance})

Properties

colliderHandle → int
final
distance → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worldNormal → Vector3
final
worldPoint → Vector3
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited