SimplePoseTarget class final Physics

A plain mutable pose.

Implemented types

Constructors

SimplePoseTarget({Vector3? translation, Quaternion? rotation})

Properties

hashCode int
The hash code for this object.
no setterinherited
rotation ↔ Quaternion
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translation ↔ Vector3
getter/setter pair
worldRotation → Quaternion
no setteroverride
worldTranslation → Vector3
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setWorldPose(Vector3 translation, Quaternion rotation) → void
Writes a simulated pose back. Backends call this from their interpolate step for dynamic bodies.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited