GenericJointDesc class Physics
A six-degree-of-freedom constraint with per-axis motion configs.
Constructors
-
GenericJointDesc({required int bodyA, required int bodyB, Vector3? localAnchorA, Vector3? localAnchorB, Quaternion? localBasisA, Quaternion? localBasisB, List<
JointAxisConfig> ? axes, bool collisionsEnabled = false})
Properties
-
axes
→ List<
JointAxisConfig> -
One config per JointAxis, indexed by
JointAxis.index.final - bodyA → int
-
finalinherited
- bodyB → int
-
finalinherited
- collisionsEnabled → bool
-
Whether the joined bodies still collide with each other.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- localAnchorA → Vector3
-
final
- localAnchorB → Vector3
-
final
- localBasisA → Quaternion
-
final
- localBasisB → Quaternion
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited