RevoluteJointDesc class Physics
A hinge about localAxisA/localAxisB, optionally limited and motorized.
Constructors
Properties
- bodyA → int
-
finalinherited
- bodyB → int
-
finalinherited
- collisionsEnabled → bool
-
Whether the joined bodies still collide with each other.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- localAnchorA → Vector3
-
final
- localAnchorB → Vector3
-
final
- localAxisA → Vector3
-
final
- localAxisB → Vector3
-
final
- lowerLimit → double?
-
final
- motorMaxForce → double?
-
final
- motorTargetVelocity → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upperLimit → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited