SimCollisionBegan class Physics
Contact between two colliders began this step, carrying its contacts.
- Inheritance
-
- Object
- SimCollisionEvent
- SimCollisionBegan
Constructors
-
SimCollisionBegan({required int colliderHandleA, required int colliderHandleB, List<
ContactPoint> contacts = const []})
Properties
- colliderHandleA → int
-
finalinherited
- colliderHandleB → int
-
finalinherited
-
contacts
→ List<
ContactPoint> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited