SimShapeCastHit class Physics
A shape-cast result at the simulation level.
- Inheritance
-
- Object
- SimRaycastHit
- SimShapeCastHit
Constructors
- SimShapeCastHit({required int colliderHandle, required Vector3 worldPoint, required Vector3 worldNormal, required double distance})
Properties
- colliderHandle → int
-
finalinherited
- distance → double
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worldNormal → Vector3
-
finalinherited
- worldPoint → Vector3
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited